@@ -212,7 +212,7 @@ impl Faucet {
                             )
                         );
                         let memo_instruction = Instruction {
-                            program_id: Pubkey::new(&spl_memo::id().to_bytes()),
+                            program_id: Pubkey::new(&safe_memo::id().to_bytes()),
                             accounts: vec![],
                             data: memo.as_bytes().to_vec(),
                         };
@@ -637,7 +637,7 @@ mod tests {
             assert_eq!(tx.signatures.len(), 1);
             assert_eq!(
                 message.account_keys,
-                vec![mint_pubkey, Pubkey::new(&spl_memo::id().to_bytes())]
+                vec![mint_pubkey, Pubkey::new(&safe_memo::id().to_bytes())]
             );
             assert_eq!(message.recent_blockhash, blockhash);
 
